From: Frank Cornelis <Frank.Cornelis@elis.ugent.be>
To: Frank Cornelis <Frank.Cornelis@elis.ugent.be>
Cc: linux-kernel <linux-kernel@vger.kernel.org>
Subject: Re: [PATCH] sched_best_cpu
Date: 13 Aug 2003 15:15:28 +0200 [thread overview]
Message-ID: <1060780528.2211.35.camel@tom> (raw)
In-Reply-To: <1060779608.1723.30.camel@tom>
Ok, here's the good one.
Frank.
--- sched.c.orig 2003-08-09 06:39:35.000000000 +0200
+++ sched.c 2003-08-13 15:13:00.000000000 +0200
@@ -776,7 +776,7 @@
*/
static int sched_best_cpu(struct task_struct *p)
{
- int i, minload, load, best_cpu, node = 0;
+ int i, minload, load, best_cpu, node = 0, pnode;
unsigned long cpumask;
best_cpu = task_cpu(p);
@@ -784,14 +784,15 @@
return best_cpu;
minload = 10000000;
+ pnode = cpu_to_node(task_cpu(p));
for_each_node_with_cpus(i) {
/*
* Node load is always divided by nr_cpus_node to normalise
* load values in case cpu count differs from node to node.
* We first multiply node_nr_running by 10 to get a little
* better resolution.
*/
- load = 10 * atomic_read(&node_nr_running[i]) / nr_cpus_node(i);
+ load = 10 * (atomic_read(&node_nr_running[i]) + (i != pnode)) / nr_cpus_node(i);
if (load < minload) {
minload = load;
node = i;
prev parent reply other threads:[~2003-08-13 13:17 UTC|newest]
Thread overview: 2+ messages / expand[flat|nested] mbox.gz Atom feed top
2003-08-13 13:00 [PATCH] sched_best_cpu Frank Cornelis
2003-08-13 13:15 ` Frank Cornelis [this message]
Reply instructions:
You may reply publicly to this message via plain-text email
using any one of the following methods:
* Save the following mbox file, import it into your mail client,
and reply-to-all from there: mbox
Avoid top-posting and favor interleaved quoting:
https://en.wikipedia.org/wiki/Posting_style#Interleaved_style
* Reply using the --to, --cc, and --in-reply-to
switches of git-send-email(1):
git send-email \
--in-reply-to=1060780528.2211.35.camel@tom \
--to=frank.cornelis@elis.ugent.be \
--cc=linux-kernel@vger.kernel.org \
/path/to/YOUR_REPLY
https://kernel.org/pub/software/scm/git/docs/git-send-email.html
* If your mail client supports setting the In-Reply-To header
@@ -784,14 +784,15 @@
* Node load is always divided by nr_cpus_node to normalise
* load values in case cpu count differs from node to node.
- * We first multiply node_nr_running by 10 to get a little
- * better resolution.
+ * If the node != our node we add the load of the task.
+ * We multiply by 10 for better resolution.
*/
via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line
before the message body.
This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox